@@ -36,6 +36,13 @@ class ExecCommand extends BaseCommand
                     'Arguments to pass to the binary. Use <info>--</info> to separate from composer arguments'
                 ),
             ))
+            ->setHelp(
+                <<<EOT
+Executes a vendored binary/script.
+
+Read more at https://getcomposer.org/doc/03-cli.md#exec
+EOT
+            )
         ;
     }
 
@@ -53,7 +60,8 @@ class ExecCommand extends BaseCommand
                 throw new \RuntimeException("No binaries found in composer.json or in bin-dir ($binDir)");
             }
 
-            $this->getIO()->write(<<<EOT
+            $this->getIO()->write(
+                <<<EOT
 <comment>Available binaries:</comment>
 EOT
             );
@@ -66,7 +74,8 @@ EOT
 
                 $previousBin = $bin;
                 $bin = basename($bin);
-                $this->getIO()->write(<<<EOT
+                $this->getIO()->write(
+                    <<<EOT
 <info>- $bin</info>
 EOT
                 );
@@ -83,6 +92,17 @@ EOT
             $output->setVerbosity(OutputInterface::VERBOSITY_QUIET);
         }
 
+        // If the CWD was modified, we restore it to what it was initially, as it was
+        // most likely modified by the global command, and we want exec to run in the local working directory
+        // not the global one
+        if (getcwd() !== $this->getApplication()->getInitialWorkingDirectory()) {
+            try {
+                chdir($this->getApplication()->getInitialWorkingDirectory());
+            } catch (\Exception $e) {
+                throw new \RuntimeException('Could not switch back to working directory "'.$this->getApplication()->getWorkingDirectory().'"', 0, $e);
+            }
+        }
+
         return $dispatcher->dispatchScript('__exec_command', true, $input->getArgument('args'));
     }
 }
