@@ -65,13 +65,10 @@ class ArrayLoader implements LoaderInterface
         }
 
         if (isset($config['bin'])) {
-            if (!is_array($config['bin'])) {
-                throw new \UnexpectedValueException('Package '.$config['name'].'\'s bin key should be an array, '.gettype($config['bin']).' given.');
-            }
-            foreach ($config['bin'] as $key => $bin) {
+            foreach ((array) $config['bin'] as $key => $bin) {
                 $config['bin'][$key] = ltrim($bin, '/');
             }
-            $package->setBinaries($config['bin']);
+            $package->setBinaries((array) $config['bin']);
         }
 
         if (isset($config['installation-source'])) {
@@ -88,7 +85,7 @@ class ArrayLoader implements LoaderInterface
             }
             $package->setSourceType($config['source']['type']);
             $package->setSourceUrl($config['source']['url']);
-            $package->setSourceReference($config['source']['reference']);
+            $package->setSourceReference(isset($config['source']['reference']) ? $config['source']['reference'] : null);
             if (isset($config['source']['mirrors'])) {
                 $package->setSourceMirrors($config['source']['mirrors']);
             }
@@ -201,6 +198,10 @@ class ArrayLoader implements LoaderInterface
                 $package->setSupport($config['support']);
             }
 
+            if (!empty($config['funding']) && is_array($config['funding'])) {
+                $package->setFunding($config['funding']);
+            }
+
             if (isset($config['abandoned'])) {
                 $package->setAbandoned($config['abandoned']);
             }
