@@ -17,7 +17,7 @@ use Composer\DependencyResolver\Rule;
 use Composer\DependencyResolver\RuleSet;
 use Composer\DependencyResolver\Pool;
 use Composer\Repository\ArrayRepository;
-use Composer\TestCase;
+use Composer\Test\TestCase;
 
 class RuleTest extends TestCase
 {
