@@ -619,7 +619,7 @@ composer https://github.com/old/url (push)
 
     public function testDowngradeShowsAppropriateMessage()
     {
-        $oldPackage = $this->getMock('Composer\Package\PackageInterface');
+        $oldPackage = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $oldPackage->expects($this->any())
             ->method('getVersion')
             ->will($this->returnValue('1.2.0.0'));
@@ -633,7 +633,7 @@ composer https://github.com/old/url (push)
             ->method('getSourceUrls')
             ->will($this->returnValue(array('/foo/bar', 'https://github.com/composer/composer')));
 
-        $newPackage = $this->getMock('Composer\Package\PackageInterface');
+        $newPackage = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $newPackage->expects($this->any())
             ->method('getSourceReference')
             ->will($this->returnValue('ref'));
@@ -647,12 +647,12 @@ composer https://github.com/old/url (push)
             ->method('getFullPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $processExecutor = $this->getMock('Composer\Util\ProcessExecutor');
+        $processExecutor = $this->getMockBuilder('Composer\Util\ProcessExecutor')->getMock();
         $processExecutor->expects($this->any())
             ->method('execute')
             ->will($this->returnValue(0));
 
-        $ioMock = $this->getMock('Composer\IO\IOInterface');
+        $ioMock = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
         $ioMock->expects($this->at(0))
             ->method('writeError')
             ->with($this->stringContains('Downgrading'));
@@ -664,7 +664,7 @@ composer https://github.com/old/url (push)
 
     public function testNotUsingDowngradingWithReferences()
     {
-        $oldPackage = $this->getMock('Composer\Package\PackageInterface');
+        $oldPackage = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $oldPackage->expects($this->any())
             ->method('getVersion')
             ->will($this->returnValue('dev-ref'));
@@ -675,7 +675,7 @@ composer https://github.com/old/url (push)
             ->method('getSourceUrls')
             ->will($this->returnValue(array('/foo/bar', 'https://github.com/composer/composer')));
 
-        $newPackage = $this->getMock('Composer\Package\PackageInterface');
+        $newPackage = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $newPackage->expects($this->any())
             ->method('getSourceReference')
             ->will($this->returnValue('ref'));
@@ -686,12 +686,12 @@ composer https://github.com/old/url (push)
             ->method('getVersion')
             ->will($this->returnValue('dev-ref2'));
 
-        $processExecutor = $this->getMock('Composer\Util\ProcessExecutor');
+        $processExecutor = $this->getMockBuilder('Composer\Util\ProcessExecutor')->getMock();
         $processExecutor->expects($this->any())
             ->method('execute')
             ->will($this->returnValue(0));
 
-        $ioMock = $this->getMock('Composer\IO\IOInterface');
+        $ioMock = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
         $ioMock->expects($this->at(0))
             ->method('writeError')
             ->with($this->stringContains('updating'));
@@ -712,7 +712,7 @@ composer https://github.com/old/url (push)
             ->with($this->equalTo($expectedGitResetCommand))
             ->will($this->returnValue(0));
         $filesystem = $this->getMockBuilder('Composer\Util\Filesystem')->getMock();
-        $filesystem->expects($this->any())
+        $filesystem->expects($this->once())
             ->method('removeDirectory')
             ->with($this->equalTo('composerPath'))
             ->will($this->returnValue(true));
