@@ -15,7 +15,7 @@ namespace Composer\Test\Package\Dumper;
 use Composer\Package\Dumper\ArrayDumper;
 use Composer\Package\Link;
 use Composer\Semver\Constraint\Constraint;
-use PHPUnit\Framework\TestCase;
+use Composer\Test\TestCase;
 
 class ArrayDumperTest extends TestCase
 {
@@ -191,6 +191,10 @@ class ArrayDumperTest extends TestCase
                 'support',
                 array('foo' => 'bar'),
             ),
+            array(
+                'funding',
+                array('type' => 'foo', 'url' => 'https://example.com'),
+            ),
             array(
                 'require',
                 array(new Link('foo', 'foo/bar', new Constraint('=', '1.0.0.0'), 'requires', '1.0.0'), new Link('bar', 'bar/baz', new Constraint('=', '1.0.0.0'), 'requires', '1.0.0')),
