@@ -14,7 +14,7 @@ namespace Composer\Test\Package\Loader;
 
 use Composer\Package\Loader\ValidatingArrayLoader;
 use Composer\Package\Loader\InvalidPackageException;
-use PHPUnit\Framework\TestCase;
+use Composer\Test\TestCase;
 
 class ValidatingArrayLoaderTest extends TestCase
 {
@@ -73,6 +73,15 @@ class ValidatingArrayLoaderTest extends TestCase
                         'rss' => 'http://example.org/rss',
                         'chat' => 'http://example.org/chat',
                     ),
+                    'funding' => array(
+                        array(
+                            'type' => 'example',
+                            'url' => 'https://example.org/fund'
+                        ),
+                        array(
+                            'url' => 'https://example.org/fund'
+                        ),
+                    ),
                     'require' => array(
                         'a/b' => '1.*',
                         'b/c' => '~2',
